==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectCase.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectcase_h
#define objectcase_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_case {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _case;
  int _case_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  GSList* _caseitem;
  int _caseitem_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectCaseitem.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_case_getuid (p_case mycase);
win32_interface gboolean adms_case_cmp (p_case mycase,p_case refcase);
win32_interface p_case adms_case_new_1 (p_module mymodule,p_expression mycase);
#define adms_case_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_case_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_case_new_impl (p_adms arguments[]);
win32_interface p_case adms_case_impl (void* member);
#define adms_case(member) ((p_case) (member))
#define adms_case_new adms_case_new_1
#define adms_case_isdefault_module(case) (adms_case(case)->_module_isdefault)
#define adms_case_valueof_module(case) (adms_case(case)->_module)
#define adms_case_isdefault_case(case) (adms_case(case)->_case_isdefault)
#define adms_case_valueof_case(case) (adms_case(case)->_case)
#define adms_case_isdefault_name(case) (adms_case(case)->_name_isdefault)
#define adms_case_valueof_name(case) (adms_case(case)->_name)
#define adms_case_isdefault_caseitem(case) (adms_case(case)->_caseitem_isdefault)
#define adms_case_valueof_caseitem(case) (adms_case(case)->_caseitem)
#define adms_case_valueof_math(case) ((p_math)case)
#define adms_case_valueof_adms(case) ((p_adms)case)
#define adms_case_valueto_module(a,b) ((p_case)a)->_module=(b)
win32_interface void adms_case_valueto_module_impl (p_case mycase,p_module _module);
#define adms_case_valueto_case(a,b) ((p_case)a)->_case=(b)
win32_interface void adms_case_valueto_case_impl (p_case mycase,p_expression _case);
#define adms_case_valueto_name(a,b) ((p_case)a)->_name=(b)
win32_interface void adms_case_valueto_name_impl (p_case mycase,char* _name);
#define adms_case_valueto_caseitem(a,b) ((p_case)a)->_caseitem=(b)
win32_interface void adms_case_valueto_caseitem_impl (p_case mycase,GSList* _caseitem);
win32_interface p_caseitem adms_case_list_caseitem_lookup_by_id (p_case mymycase,gpointer mycode);
win32_interface p_caseitem adms_case_list_caseitem_prepend_by_id (p_case mymycase,gpointer mycode);
win32_interface p_caseitem adms_case_list_caseitem_prepend_by_id_once_or_ignore (p_case mymycase,gpointer mycode);
win32_interface void adms_case_list_caseitem_prepend_once_or_ignore (p_case mymycase,p_caseitem mycaseitem);
#endif /* objectcase_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectCase.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectcase_h
#define objectcase_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_case {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _case;
  int _case_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_slist _caseitem;
  int _caseitem_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectCaseitem.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_case_uid (p_case mycase);
win32_interface int adms_case_cmp (p_case mycase,p_case refcase);
win32_interface p_case adms_case_new(p_module mymodule,p_expression mycase);
win32_interface p_adms adms_case_new_impl (p_adms arguments[]);
#define adms_case(member) ((p_case) (member))
#define adms_case_isdefault_module(case) (adms_case(case)->_module_isdefault)
#define adms_case_valueof_module(case) (adms_case(case)->_module)
#define adms_case_isdefault_case(case) (adms_case(case)->_case_isdefault)
#define adms_case_valueof_case(case) (adms_case(case)->_case)
#define adms_case_isdefault_name(case) (adms_case(case)->_name_isdefault)
#define adms_case_valueof_name(case) (adms_case(case)->_name)
#define adms_case_isdefault_caseitem(case) (adms_case(case)->_caseitem_isdefault)
#define adms_case_valueof_caseitem(case) (adms_case(case)->_caseitem)
#define adms_case_valueof_math(case) ((p_math)case)
#define adms_case_valueof_adms(case) ((p_adms)case)
win32_interface inline void adms_case_valueto_module (p_case mycase,p_module _module);
win32_interface inline void adms_case_valueto_case (p_case mycase,p_expression _case);
win32_interface inline void adms_case_valueto_name (p_case mycase,p_quark _name);
win32_interface inline void adms_case_valueto_caseitem (p_case mycase,p_slist _caseitem);
win32_interface p_caseitem adms_case_list_caseitem_lookup_by_id (p_case mymycase,p_adms mycode);
win32_interface p_caseitem adms_case_list_caseitem_prepend_by_id (p_case mymycase,p_adms mycode);
win32_interface p_caseitem adms_case_list_caseitem_prepend_by_id_once_or_ignore (p_case mymycase,p_adms mycode);
win32_interface void adms_case_list_caseitem_prepend_once_or_ignore (p_case mymycase,p_caseitem mycaseitem);
win32_interface inline void adms_case_free(p_case mycase);
#endif /* objectcase_h */
